# jhub-vscode-labext

JupyterLab extension that adds an "Open in VS Code" button to JupyterHub.

## Install

```bash
pip install jhub-vscode-labext
```

Requires the [jhub-ssh gateway](https://github.com/groundsada/Jupyter-Agent) to be deployed in your JupyterHub cluster.
